@@ -21,8 +21,9 @@
 # Import from itools
 from itools.datatypes import DataType, Date, Enumerate, Boolean
 from itools.gettext import MSG
-from itools.html import xhtml_doctype, sanitize_stream
+from itools.handlers import merge_dicts
 from itools.html import stream_to_str_as_xhtml, stream_to_str_as_html
+from itools.html import xhtml_doctype, sanitize_stream
 from itools.stl import stl
 from itools.web import STLForm, get_context
 from itools.xml import XMLParser
@@ -439,19 +440,29 @@ class DateWidget(Widget):
 
 class PathSelectorWidget(TextWidget):
 
+    target = '.'
     template = list(XMLParser(
     """
     <input type="text" id="selector_${name}" size="${size}" name="${name}"
       value="${value}" />
     <input id="selector_button_${name}" type="button" value="..."
       name="selector_button_${name}"
-      onclick="popup(';add_link?target_id=selector_${name}&amp;mode=input', 620, 300);"/>
+      onclick="popup(';add_link?target_id=selector_${name}&amp;mode=input&amp;bc_target=${target}', 620, 300);"/>
     """, stl_namespaces))
 
 
+    def get_namespace(self, datatype, value):
+        namespace = TextWidget.get_namespace(self, datatype, value)
+        namespace['target'] = self.target
+        return namespace
+
+
 
 class ImageSelectorWidget(TextWidget):
 
+    width = 128
+    height = 128
+
     template = list(XMLParser(
     """
     <input type="text" id="selector_${name}" size="${size}" name="${name}"
@@ -460,10 +471,15 @@ class ImageSelectorWidget(TextWidget):
       name="selector_button_${name}"
       onclick="popup(';add_image?target_id=selector_${name}&amp;mode=input', 620, 300);" />
     <br/>
-    <img src="${value}/;thumb?width=128&amp;height=128" stl:if="value"/>
+    <img src="${value}/;thumb?width=${width}&amp;height=${height}" stl:if="value"/>
     """, stl_namespaces))
 
 
+    def get_namespace(self, datatype, value):
+        return merge_dicts(TextWidget.get_namespace(self, datatype, value),
+                           width=self.width, height=self.height)
+
+
 
 class RTEWidget(Widget):
 
