@@ -15,13 +15,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-# Import from the Standard Library
-from mimetypes import add_type
-
 # Import from itools
 from itools.datatypes import DataType, String, Unicode, XMLContent
 from itools.handlers import File, register_handler_class
-from itools.utils import freeze
+from itools.utils import freeze, add_type
 from itools.web import get_context
 from itools.xml import xml_uri, XMLParser, START_ELEMENT, END_ELEMENT, TEXT
 
