@@ -359,7 +359,9 @@ function changedType(t) {
 	d.getElementById('shockwave_options').style.display = 'none';
 	d.getElementById('wmp_options').style.display = 'none';
 	d.getElementById('rmp_options').style.display = 'none';
-	d.getElementById(t + '_options').style.display = 'block';
+
+	if (t)
+		d.getElementById(t + '_options').style.display = 'block';
 }
 
 function serializeParameters() {
@@ -600,7 +602,7 @@ function generatePreview(c) {
 
 	// Avoid annoying warning about insecure items
 	if (!tinymce.isIE || document.location.protocol != 'https:') {
-		h += '<object classid="clsid:' + cls + '" codebase="' + codebase + '" width="' + pl.width + '" height="' + pl.height + '" id="' + pl.id + '" name="' + pl.name + '" align="' + pl.align + '">';
+		h += '<object classid="' + cls + '" codebase="' + codebase + '" width="' + pl.width + '" height="' + pl.height + '" id="' + pl.id + '" name="' + pl.name + '" align="' + pl.align + '">';
 
 		for (n in pl) {
 			h += '<param name="' + n + '" value="' + pl[n] + '">';
